.. _examples:

Cookbook and Examples
=====================

Below is a list of examples on how to use ``mvmlib`` to solve practical design problems and quantify design margins for them.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   notebooks/TRS_example
   notebooks/strut_example
   notebooks/PDF_examples